@@ -23,6 +23,8 @@
 
 int main(int argc, char *argv[])
 {
+    qDebug() << "started";
+
     QApplication a(argc, argv);
     a.setAutoSipEnabled(false);
     a.setApplicationVersion(APP_VERSION);
@@ -35,7 +37,6 @@ int main(int argc, char *argv[])
     w.showMaximized();
 #else
     w.show();
-    //w.showFullScreen();
 #endif
 
     return a.exec();
